﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using System.Xml;

namespace TestProject
{
    /// <summary>
    /// 도움말 윈도우
    /// </summary>
    public partial class HelpWindow 
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - HelpWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public HelpWindow()
        {
            InitializeComponent();

            this.treeView.Focus();
        }

        #endregion
        #region 생성자 - HelpWindow(topicURI)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="topicURI">항목 URI</param>
        public HelpWindow(string topicURI) : this()
        {
            if(topicURI != null)
            {
                this.frame.Source = new Uri(topicURI, UriKind.Relative);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 트리 뷰 선택 항목 변경시 처리하기 - treeView_SelectedItemChanged(sender, e)

        /// <summary>
        /// 트리 뷰 선택 항목 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeView_SelectedItemChanged(object sender, RoutedPropertyChangedEventArgs<object> e)
        {
            if(this.treeView.SelectedValue != null)
            {
                this.frame.Source = new Uri(this.treeView.SelectedValue as string, UriKind.Relative);
            }
        }

        #endregion
        #region 프레임 탐색시 처리하기 - frame_Navigated(sender, e)

        /// <summary>
        /// 프레임 탐색시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void frame_Navigated(object sender, NavigationEventArgs e)
        {
            if(e.Uri != null && e.Uri.OriginalString != null && e.Uri.OriginalString.Length > 0)
            {
                FindItemToSelect(this.treeView, e.Uri.OriginalString);
            }
        }

        #endregion
        #region 선택하기 위한 항목 찾기 - FindItemToSelect(itemsControl, source)

        /// <summary>
        /// 선택하기 위한 항목 찾기
        /// </summary>
        /// <param name="itemsControl">ItemsControl 객체</param>
        /// <param name="source">소스 문자열</param>
        /// <returns>처리 결과</returns>
        private bool FindItemToSelect(ItemsControl itemsControl, string source)
        {
            foreach(object item in itemsControl.Items)
            {
                XmlElement xmlElement = item as XmlElement;

                string attribute = xmlElement.GetAttribute("Source");

                TreeViewItem treeViewItem = itemsControl.ItemContainerGenerator.ContainerFromItem(item) as TreeViewItem;

                if(attribute != null && attribute.Length > 0 && source.EndsWith(attribute))
                {
                    if(treeViewItem != null && !treeViewItem.IsSelected)
                    {
                        treeViewItem.IsSelected = true;
                    }

                    return true;
                }

                if(treeViewItem != null)
                {
                    bool bIsExpanded = treeViewItem.IsExpanded;

                    treeViewItem.IsExpanded = true;

                    if(treeViewItem.HasItems && FindItemToSelect(treeViewItem, source))
                    {
                        return true;
                    }

                    treeViewItem.IsExpanded = bIsExpanded;
                }
            }

            return false;
        }

        #endregion
    }
}